@@ -28,7 +28,7 @@ func init() {
 
 // I2C on the ItsyBitsy M4.
 var (
-	I2C0 = I2C{
+	I2C0 = &I2C{
 		Bus:    sam.SERCOM2_I2CM,
 		SERCOM: 2,
 	}
